Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/usr.bin/rdist fix various typos, mainly s/trasfering/transfe...



details:   https://anonhg.NetBSD.org/src/rev/9af805e9fede
branches:  trunk
changeset: 365931:9af805e9fede
user:      andvar <andvar%NetBSD.org@localhost>
date:      Tue May 03 20:52:30 2022 +0000

description:
fix various typos, mainly s/trasfering/transferring/ and s/theese/these/.

diffstat:

 distrib/atari/floppies/prepare/install.sh  |  4 ++--
 distrib/miniroot/install.sh                |  4 ++--
 doc/TODO.smpnet                            |  4 ++--
 sys/arch/acorn32/podulebus/sbic.c          |  6 +++---
 sys/arch/amiga/dev/grf_rh.c                |  6 +++---
 sys/arch/amiga/dev/grf_rhreg.h             |  6 +++---
 sys/arch/amiga/dev/grf_rt.c                |  6 +++---
 sys/arch/amiga/dev/grf_rtreg.h             |  6 +++---
 sys/arch/arc/include/isa_machdep.h         |  4 ++--
 sys/arch/atari/dev/fd.c                    |  6 +++---
 sys/arch/mipsco/obio/asc.c                 |  6 +++---
 sys/arch/pmax/tc/asc_ioasic.c              |  6 +++---
 sys/arch/powerpc/powerpc/powerpc_machdep.c |  6 +++---
 sys/arch/sparc64/sparc64/ipifuncs.c        |  6 +++---
 sys/arch/sun3/sun3x/pmap.c                 |  6 +++---
 sys/coda/coda_psdev.c                      |  6 +++---
 sys/dev/ic/ispreg.h                        |  4 ++--
 sys/dev/ic/sl811hs.c                       |  6 +++---
 sys/dev/pci/if_sk.c                        |  6 +++---
 sys/fs/udf/udf_vnops.c                     |  6 +++---
 usr.bin/rdist/main.c                       |  6 +++---
 21 files changed, 58 insertions(+), 58 deletions(-)

diffs (truncated from 524 to 300 lines):

diff -r 8fd72715c143 -r 9af805e9fede distrib/atari/floppies/prepare/install.sh
--- a/distrib/atari/floppies/prepare/install.sh Tue May 03 20:12:27 2022 +0000
+++ b/distrib/atari/floppies/prepare/install.sh Tue May 03 20:52:30 2022 +0000
@@ -1,5 +1,5 @@
 #!/bin/sh
-#      $NetBSD: install.sh,v 1.3 2016/09/18 18:24:00 christos Exp $
+#      $NetBSD: install.sh,v 1.4 2022/05/03 20:52:30 andvar Exp $
 #
 # Copyright (c) 1996 The NetBSD Foundation, Inc.
 # All rights reserved.
@@ -33,7 +33,7 @@
 #      In a perfect world, this would be a nice C program, with a reasonable
 #      user interface.
 
-FILESYSTEMS="/tmp/filesystems"         # used thoughout
+FILESYSTEMS="/tmp/filesystems"         # used throughout
 MODE="install"
 
 # include machine-dependent functions
diff -r 8fd72715c143 -r 9af805e9fede distrib/miniroot/install.sh
--- a/distrib/miniroot/install.sh       Tue May 03 20:12:27 2022 +0000
+++ b/distrib/miniroot/install.sh       Tue May 03 20:52:30 2022 +0000
@@ -1,5 +1,5 @@
 #!/bin/sh
-#      $NetBSD: install.sh,v 1.27 2019/04/04 20:51:35 christos Exp $
+#      $NetBSD: install.sh,v 1.28 2022/05/03 20:52:30 andvar Exp $
 #
 # Copyright (c) 1996,1997,1999,2000,2006 The NetBSD Foundation, Inc.
 # All rights reserved.
@@ -33,7 +33,7 @@
 #      In a perfect world, this would be a nice C program, with a reasonable
 #      user interface.
 
-FILESYSTEMS="/tmp/filesystems"         # used thoughout
+FILESYSTEMS="/tmp/filesystems"         # used throughout
 FQDN=""                                        # domain name
 
 trap "umount /tmp > /dev/null 2>&1" 0
diff -r 8fd72715c143 -r 9af805e9fede doc/TODO.smpnet
--- a/doc/TODO.smpnet   Tue May 03 20:12:27 2022 +0000
+++ b/doc/TODO.smpnet   Tue May 03 20:52:30 2022 +0000
@@ -1,4 +1,4 @@
-$NetBSD: TODO.smpnet,v 1.45 2021/12/31 00:57:12 riastradh Exp $
+$NetBSD: TODO.smpnet,v 1.46 2022/05/03 20:52:30 andvar Exp $
 
 MP-safe components
 ==================
@@ -171,7 +171,7 @@
 (struct ifnet), and traverses each object through ifnet#if_list member variable.
 ifnet_list and ifnet#if_list is obsoleted by ifnet_pslist and
 ifnet#if_pslist_entry respectively. netstat also accesses the IP address list
-of an interface throught ifnet#if_addrlist. struct ifaddr, struct in_ifaddr
+of an interface through ifnet#if_addrlist. struct ifaddr, struct in_ifaddr
 and struct in6_ifaddr are accessed and the following obsolete member variables
 are stuck: ifaddr#ifa_list, in_ifaddr#ia_hash, in_ifaddr#ia_list,
 in6_ifaddr#ia_next and in6_ifaddr#_ia6_multiaddrs. Note that netstat already
diff -r 8fd72715c143 -r 9af805e9fede sys/arch/acorn32/podulebus/sbic.c
--- a/sys/arch/acorn32/podulebus/sbic.c Tue May 03 20:12:27 2022 +0000
+++ b/sys/arch/acorn32/podulebus/sbic.c Tue May 03 20:52:30 2022 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: sbic.c,v 1.17 2012/10/27 17:17:23 chs Exp $ */
+/* $NetBSD: sbic.c,v 1.18 2022/05/03 20:52:30 andvar Exp $ */
 
 /*
  * Copyright (c) 2001 Richard Earnshaw
@@ -114,7 +114,7 @@
 
 #include <sys/param.h>
 
-__KERNEL_RCSID(0, "$NetBSD: sbic.c,v 1.17 2012/10/27 17:17:23 chs Exp $");
+__KERNEL_RCSID(0, "$NetBSD: sbic.c,v 1.18 2022/05/03 20:52:30 andvar Exp $");
 
 #include <sys/systm.h>
 #include <sys/callout.h>
@@ -2130,7 +2130,7 @@
                        acb->sc_tcnt =
                            dev->sc_dmanext(dev->sc_dmah, dev->sc_dmat,
                                acb, acb->offset);
-                       DBGPRINTF(("dmanext transfering %ld bytes\n",
+                       DBGPRINTF(("dmanext transferring %ld bytes\n",
                            acb->sc_tcnt), data_pointer_debug);
                        SBIC_TC_PUT(regs, (unsigned)acb->sc_tcnt);
                        SET_SBIC_cmd(regs, SBIC_CMD_XFER_INFO);
diff -r 8fd72715c143 -r 9af805e9fede sys/arch/amiga/dev/grf_rh.c
--- a/sys/arch/amiga/dev/grf_rh.c       Tue May 03 20:12:27 2022 +0000
+++ b/sys/arch/amiga/dev/grf_rh.c       Tue May 03 20:52:30 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: grf_rh.c,v 1.61 2022/03/28 12:38:57 riastradh Exp $ */
+/*     $NetBSD: grf_rh.c,v 1.62 2022/05/03 20:52:30 andvar Exp $ */
 
 /*
  * Copyright (c) 1994 Markus Wild
@@ -34,7 +34,7 @@
 #include "opt_retina.h"
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: grf_rh.c,v 1.61 2022/03/28 12:38:57 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: grf_rh.c,v 1.62 2022/05/03 20:52:30 andvar Exp $");
 
 #include "grfrh.h"
 #include "ite.h"
@@ -106,7 +106,7 @@
  * for the Amiga.
  *
  * Thanks to MacroSystem for providing me with the necessary information
- * to create theese routines. The sparse documentation of this code
+ * to create these routines. The sparse documentation of this code
  * results from the agreements between MS and me.
  */
 
diff -r 8fd72715c143 -r 9af805e9fede sys/arch/amiga/dev/grf_rhreg.h
--- a/sys/arch/amiga/dev/grf_rhreg.h    Tue May 03 20:12:27 2022 +0000
+++ b/sys/arch/amiga/dev/grf_rhreg.h    Tue May 03 20:52:30 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: grf_rhreg.h,v 1.16 2007/03/04 05:59:19 christos Exp $  */
+/*     $NetBSD: grf_rhreg.h,v 1.17 2022/05/03 20:52:30 andvar Exp $    */
 
 /*
  * Copyright (c) 1994 Markus Wild
@@ -198,7 +198,7 @@
  * You may set a character and its associated attribute byte
  * with a single word-access, or you may perform to byte writes
  * for the char and attribute. Each 2. word has no meaning,
- * and writes to theese locations are ignored.
+ * and writes to these locations are ignored.
  *
  * The attribute byte for each character has the following
  * structure:
@@ -342,7 +342,7 @@
  * parameters have sensible values. 8 bit gfx-mode only!
  *
  * The blitter has a lot more capabilities, which aren't
- * currently used by theese routines, among them color-expanded
+ * currently used by these routines, among them color-expanded
  * and text-blits, which can speed up GUIs like X11 a lot.
  * If you've got any idea how to make use of them within
  * your routines, contact me, and I'll implement the necessary
diff -r 8fd72715c143 -r 9af805e9fede sys/arch/amiga/dev/grf_rt.c
--- a/sys/arch/amiga/dev/grf_rt.c       Tue May 03 20:12:27 2022 +0000
+++ b/sys/arch/amiga/dev/grf_rt.c       Tue May 03 20:52:30 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: grf_rt.c,v 1.61 2022/03/28 12:38:57 riastradh Exp $ */
+/*     $NetBSD: grf_rt.c,v 1.62 2022/05/03 20:52:30 andvar Exp $ */
 
 /*
  * Copyright (c) 1993 Markus Wild
@@ -33,7 +33,7 @@
 #include "opt_amigacons.h"
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: grf_rt.c,v 1.61 2022/03/28 12:38:57 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: grf_rt.c,v 1.62 2022/05/03 20:52:30 andvar Exp $");
 
 #include "grfrt.h"
 #include "ite.h"
@@ -80,7 +80,7 @@
  * manufactured by MS MacroSystem GmbH from within NetBSD for the Amiga.
  *
  * Thanks to MacroSystem for providing me with the necessary information
- * to create theese routines. The sparse documentation of this code
+ * to create these routines. The sparse documentation of this code
  * results from the agreements between MS and me.
  */
 
diff -r 8fd72715c143 -r 9af805e9fede sys/arch/arc/include/isa_machdep.h
--- a/sys/arch/arc/include/isa_machdep.h        Tue May 03 20:12:27 2022 +0000
+++ b/sys/arch/arc/include/isa_machdep.h        Tue May 03 20:52:30 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: isa_machdep.h,v 1.17 2016/10/18 22:04:33 jdolecek Exp $        */
+/*     $NetBSD: isa_machdep.h,v 1.18 2022/05/03 20:52:31 andvar Exp $  */
 /*      $OpenBSD: isa_machdep.h,v 1.5 1997/04/19 17:20:00 pefo Exp $  */
 
 /*
@@ -39,7 +39,7 @@
 
 /*
  *      I/O macros to access isa bus ports/memory.
- *      At the first glance theese macros may seem inefficient.
+ *      At the first glance these macros may seem inefficient.
  *      However, the CPU executes an instruction every 7.5ns
  *      so the bus is much slower so it doesn't matter, really.
  */
diff -r 8fd72715c143 -r 9af805e9fede sys/arch/atari/dev/fd.c
--- a/sys/arch/atari/dev/fd.c   Tue May 03 20:12:27 2022 +0000
+++ b/sys/arch/atari/dev/fd.c   Tue May 03 20:52:30 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: fd.c,v 1.90 2022/04/11 21:23:07 andvar Exp $   */
+/*     $NetBSD: fd.c,v 1.91 2022/05/03 20:52:31 andvar Exp $   */
 
 /*
  * Copyright (c) 1995 Leo Weppelman.
@@ -44,7 +44,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: fd.c,v 1.90 2022/04/11 21:23:07 andvar Exp $");
+__KERNEL_RCSID(0, "$NetBSD: fd.c,v 1.91 2022/05/03 20:52:31 andvar Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -555,7 +555,7 @@
                 * floppy (eq. the same partition).
                 */
                if (sc->density != fdtypes[DISKPART(dev)].density)
-                       return ENXIO;   /* XXX temporarely out of business */
+                       return ENXIO;   /* XXX temporarily out of business */
        }
        fdgetdisklabel(sc, dev);
 #ifdef FLP_DEBUG
diff -r 8fd72715c143 -r 9af805e9fede sys/arch/mipsco/obio/asc.c
--- a/sys/arch/mipsco/obio/asc.c        Tue May 03 20:12:27 2022 +0000
+++ b/sys/arch/mipsco/obio/asc.c        Tue May 03 20:52:30 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: asc.c,v 1.22 2008/04/28 20:23:28 martin Exp $  */
+/*     $NetBSD: asc.c,v 1.23 2022/05/03 20:52:31 andvar Exp $  */
 /*-
  * Copyright (c) 2000 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -29,7 +29,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: asc.c,v 1.22 2008/04/28 20:23:28 martin Exp $");
+__KERNEL_RCSID(0, "$NetBSD: asc.c,v 1.23 2022/05/03 20:52:31 andvar Exp $");
 
 #include <sys/types.h>
 #include <sys/param.h>
@@ -311,7 +311,7 @@
        if (esc->sc_dmasize == 0)
                return 0;
 
-       /* have dmamap for the transfering addresses */
+       /* have dmamap for the transferring addresses */
        if ((err = bus_dmamap_load(esc->sc_dmat, esc->sc_dmamap,
            *esc->sc_dmaaddr, esc->sc_dmasize, NULL /* kernel address */,                   BUS_DMA_NOWAIT)) != 0)
                panic("%s: bus_dmamap_load err=%d",
diff -r 8fd72715c143 -r 9af805e9fede sys/arch/pmax/tc/asc_ioasic.c
--- a/sys/arch/pmax/tc/asc_ioasic.c     Tue May 03 20:12:27 2022 +0000
+++ b/sys/arch/pmax/tc/asc_ioasic.c     Tue May 03 20:52:30 2022 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: asc_ioasic.c,v 1.26 2018/09/03 16:29:26 riastradh Exp $ */
+/* $NetBSD: asc_ioasic.c,v 1.27 2022/05/03 20:52:31 andvar Exp $ */
 
 /*-
  * Copyright (c) 2000 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>                 /* RCS ID & Copyright macro defns */
-__KERNEL_RCSID(0, "$NetBSD: asc_ioasic.c,v 1.26 2018/09/03 16:29:26 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: asc_ioasic.c,v 1.27 2022/05/03 20:52:31 andvar Exp $");
 
 #include <sys/param.h>
 #include <sys/buf.h>
@@ -234,7 +234,7 @@
        ssr &= ~IOASIC_CSR_DMAEN_SCSI;
        bus_space_write_4(asc->sc_bst, asc->sc_bsh, IOASIC_CSR, ssr);
 
-       /* have dmamap for the transfering addresses */
+       /* have dmamap for the transferring addresses */
        if (bus_dmamap_load(asc->sc_dmat, asc->sc_dmamap,
            *addr, size, NULL /* kernel address */, BUS_DMA_NOWAIT))
                panic("%s: cannot allocate DMA address",
diff -r 8fd72715c143 -r 9af805e9fede sys/arch/powerpc/powerpc/powerpc_machdep.c
--- a/sys/arch/powerpc/powerpc/powerpc_machdep.c        Tue May 03 20:12:27 2022 +0000
+++ b/sys/arch/powerpc/powerpc/powerpc_machdep.c        Tue May 03 20:52:30 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: powerpc_machdep.c,v 1.83 2021/04/15 00:04:07 rin Exp $ */
+/*     $NetBSD: powerpc_machdep.c,v 1.84 2022/05/03 20:52:31 andvar Exp $      */
 
 /*
  * Copyright (C) 1995, 1996 Wolfgang Solfrank.
@@ -32,7 +32,7 @@



Home | Main Index | Thread Index | Old Index
diff -r 8fd72715c143 -r 9af805e9fede sys/arch/amiga/dev/grf_rtreg.h
--- a/sys/arch/amiga/dev/grf_rtreg.h    Tue May 03 20:12:27 2022 +0000
+++ b/sys/arch/amiga/dev/grf_rtreg.h    Tue May 03 20:52:30 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: grf_rtreg.h,v 1.16 2010/02/28 15:52:16 snj Exp $       */
+/*     $NetBSD: grf_rtreg.h,v 1.17 2022/05/03 20:52:30 andvar Exp $    */
 
 /*
  * Copyright (c) 1993 Markus Wild
@@ -50,7 +50,7 @@
  * manufactured by MS MacroSystem GmbH from within NetBSD for the Amiga.
  *
  * Thanks to MacroSystem for providing me with the necessary information
  * to create theese routines. The sparse documentation of this code
  * results from the agreements between MS and me.
  */
 
@@ -204,7 +204,7 @@
    You may set a character and its associated attribute byte
    with a single word-access, or you may perform to byte writes
    for the char and attribute. Each 2. word has no meaning,
-   and writes to theese locations are ignored.
+   and writes to these locations are ignored.
 
    The attribute byte for each character has the following
    structure:
@@ -50,7 +50,7 @@
  *
  * Thanks to MacroSystem for providing me with the necessary information
- * to create theese routines. The sparse documentation of this code
+ * to create these routines. The sparse documentation of this code
  * results from the agreements between MS and me.
  */